@@ -34,12 +34,12 @@
 #'   \item The names of any scripts sourced
 #'   \item The names of files input or output, the file timestamp, and its hashvalue
 #'   \item Any URLs loaded and the time loaded
-#'   \item Any errors or warnings along with the line on which they occurred, if known.
 #'   \item Any messages sent to standard output along with the line on which they occurred, if known.
+#'   \item Any errors or warnings along with the line on which they occurred, if known.
 #' }
 #' 
-#' For provenance collected from a console session, only the environment and library information
-#' appears in the summary.
+#' For provenance collected from a console session, only the environment, library, file, and URL
+#' information appears in the summary.
 #' 
 #' Creating a zip file depends on a zip executable being on the search path.
 #' By default, it looks for a program named zip.  To use a program with 
@@ -202,11 +202,15 @@ generate.summaries <- function(prov, environment) {
   
   generate.environment.summary (environment, provParseR::get.tool.info(prov), script.file)
   generate.library.summary (provParseR::get.libs(prov))
-  
+
   if (script.file != "") {
     generate.script.summary (provParseR::get.scripts(prov))
-    generate.file.summary ("INPUTS:", provParseR::get.input.files(prov), prov)
-    generate.file.summary ("OUTPUTS:", provParseR::get.output.files(prov), prov)
+  }
+  
+  generate.file.summary ("INPUTS:", provParseR::get.input.files(prov), prov)
+  generate.file.summary ("OUTPUTS:", provParseR::get.output.files(prov), prov)
+
+  if (script.file != "") {
     generate.stdout.summary (prov)
     generate.error.summary (prov)
   }
